@@ -7,7 +7,8 @@ or a plane and GJK is slower when one of the objects is a point or a line
 segment.
 
 In the following table an X indicates that the distance computation between
-two geometric objects is implemented.
+two geometric objects is implemented. G means the pair of shapes is covered
+by GJK.
 
 .. raw:: html
 
@@ -63,10 +64,10 @@ two geometric objects is implemented.
         <td>X</td>
         <td>X</td>
         <td>X</td>
-        <td>-</td>
+        <td>G</td>
         <td>X</td>
-        <td>-</td>
-        <td>-</td>
+        <td>G</td>
+        <td>G</td>
       </tr>
       <tr>
         <td>plane</td>
@@ -91,10 +92,10 @@ two geometric objects is implemented.
         <td>X</td>
         <td>X</td>
         <td>-</td>
-        <td>-</td>
-        <td>-</td>
-        <td>-</td>
-        <td>-</td>
+        <td>G</td>
+        <td>G</td>
+        <td>G</td>
+        <td>G</td>
       </tr>
       <tr>
         <td>rectangle</td>
@@ -103,12 +104,12 @@ two geometric objects is implemented.
         <td>X</td>
         <td>X</td>
         <td>X</td>
+        <td>G</td>
         <td>-</td>
-        <td>-</td>
-        <td>-</td>
-        <td>-</td>
-        <td>-</td>
-        <td>-</td>
+        <td>G</td>
+        <td>G</td>
+        <td>G</td>
+        <td>G</td>
       </tr>
       <tr>
         <td>circle</td>
@@ -128,15 +129,15 @@ two geometric objects is implemented.
         <td>disk</td>
         <td>X</td>
         <td>-</td>
+        <td>G</td>
         <td>-</td>
-        <td>-</td>
-        <td>-</td>
-        <td>-</td>
+        <td>G</td>
+        <td>G</td>
         <td>-</td>
         <td>X</td>
-        <td>-</td>
-        <td>-</td>
-        <td>-</td>
+        <td>G</td>
+        <td>G</td>
+        <td>G</td>
       </tr>
       <tr>
         <td>box</td>
@@ -144,41 +145,41 @@ two geometric objects is implemented.
         <td>X</td>
         <td>X</td>
         <td>X</td>
+        <td>G</td>
+        <td>G</td>
         <td>-</td>
-        <td>-</td>
-        <td>-</td>
-        <td>-</td>
-        <td>-</td>
-        <td>-</td>
-        <td>-</td>
+        <td>G</td>
+        <td>G</td>
+        <td>G</td>
+        <td>G</td>
       </tr>
       <tr>
         <td>ellipsoid</td>
         <td>X</td>
         <td>-</td>
-        <td>-</td>
+        <td>G</td>
         <td>X</td>
+        <td>G</td>
+        <td>G</td>
         <td>-</td>
-        <td>-</td>
-        <td>-</td>
-        <td>-</td>
-        <td>-</td>
-        <td>-</td>
-        <td>-</td>
+        <td>G</td>
+        <td>G</td>
+        <td>G</td>
+        <td>G</td>
       </tr>
       <tr>
         <td>cylinder</td>
         <td>X</td>
         <td>-</td>
+        <td>G</td>
         <td>-</td>
+        <td>G</td>
+        <td>G</td>
         <td>-</td>
-        <td>-</td>
-        <td>-</td>
-        <td>-</td>
-        <td>-</td>
-        <td>-</td>
-        <td>-</td>
-        <td>-</td>
+        <td>G</td>
+        <td>G</td>
+        <td>G</td>
+        <td>G</td>
       </tr>
     </table>
 """
